@@ -3,6 +3,8 @@ mod extension_supported_point_formats_test;
 
 use super::*;
 
+use anyhow::Result;
+
 const EXTENSION_SUPPORTED_POINT_FORMATS_SIZE: usize = 5;
 
 pub type EllipticCurvePointFormat = u8;
@@ -24,7 +26,7 @@ impl ExtensionSupportedPointFormats {
         2 + 1 + self.point_formats.len()
     }
 
-    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<(), Error> {
+    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<()> {
         writer.write_u16::<BigEndian>(1 + self.point_formats.len() as u16)?;
         writer.write_u8(self.point_formats.len() as u8)?;
         for v in &self.point_formats {
@@ -34,7 +36,7 @@ impl ExtensionSupportedPointFormats {
         Ok(writer.flush()?)
     }
 
-    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self, Error> {
+    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self> {
         let _ = reader.read_u16::<BigEndian>()?;
 
         let point_format_count = reader.read_u8()? as usize;
